Monty Python's Flying Circus: Just the Words - Episode 18

# Episode Eighteen

Live from the Grill-o-Mat snack bar, Paignton
'Blackmail'
Society for Putting Things on top of Other Things
Escape (from film)
Current affairs
Accidents sketch
Seven Brides for Seven Brothers
The man who is alternately rude and polite
Documentary on boxer

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| BBC world symbol
Voice Over | Monty Python's Flying Circus tonight comes to you live from the Grillomat Snack Bar, Paignton.
| Interior of a nasty snack bar. Customers around, preferably real people. Linkman sitting at one of the plastic tables.
Linkman | Hello to you live from the Grillomat Snack Bar, Paignton. And so, without any more ado, let's have the titles.
It's Man Voice | It's...
| Animated titles. Back to the snack bar.
Linkman | (with rather forced bonhomie) Well, those were the titles. And now for the first item this evening on the Menu - ha ha - the team have chosen as a little hors d'oeuvres an item - and I think we can be sure it won't be an ordinary item - in fact the team told me just before the show that anything could happen, and probably would - so let's have ... the item.
| Cut to the word 'Blackmail' in letters four feet high, picked out in lightbulbs which flash on and off. Big showbiz music crashes in. Camera pulls back to reveal glittery showbiz set. A presenter in glittery showbiz jacket sits behind a glittery desk, with a telephone on it.
Presenter | Hello, good evening, and welcome to 'Blackmail'! And to start tonight's programme, we go to Preston in Lancashire, and Mrs Betty Teal!
| Cut to a slightly blurred black and white photo of a housewife with her face blotted out by a black oblong.
Presenter | Hello, Mrs Teal!
| Cut back to presenter. He picks up a letter and reads it.
Presenter | Now this is for £15 and it's to stop us revealing the name of your lover in Bolton.
| SUPERIMPOSED CAPTION: '£15' (which flashes on and off quickly)
Presenter | So Mrs Teal...if you send us £15 by return post, please, and your husband Trevor, and your lovely children, Diane, Janice and Juliet need never know the name of your lover in Bolton.
| Cut to a nude man (except for a collar and a tie) at organ. He plays a few stirring chords. Cut back to presenter.
Presenter | (as he speaks he holds up the various items) And now...a letter...a hotel registration book...and a series of photographs...which could add up to divorce, premature retirement, and possible criminal proceedings for a company director in Bromsgrove. He's a freemason, and prospective Tory MP.. that's Mr S. of Bromsgrove...£3,000...
| SUPERIMPOSED CAPTION: '£3000' (which flashes on and off)
Presenter | ...to stop us from revealing your name, the name of the three other people involved, the youth organization to which they belong, and the shop where you bought the equipment.
| Cut back to nude man at organ with chords again. Cut to still of two pairs of naked feet and lower legs. Organ music over this. Cut back to presenter.
Presenter | We'll be showing you more of that photograph later in the programme...unless we hear from Charles or Michael. And now it's time for our 'Stop the Film' spot!
| SUPERIMPOSED FLASHING CAPTION: 'STOP THE FILM'
Presenter | The rules are very simple. We have taken a film which contains compromising scenes and unpleasant details, which could wreck a man's career. But, the victim may phone me at any point and stop the film. But remember the money increases as the film goes on. So the longer you leave it...the more you have to pay! So now, with the clock at £300 this week 'Stop the Film' visited Thames Ditton...
| The following film is shot in murky 8mm. As the film progresses we have a £ sign with numerals in one corner which increase. Shot of a residental street in Thames Ditton (sic). Another section of a street with a figure in a Robin Hood hat and raincoat - in the distance on the far side of the road, so we can't really make him out. Cut to slightly closer shot of him about to cross the road. Cut to suburban house. The man is standing at the door pressing the bell and looking round rather furtively. Again shot from some distance and over a hedge. Cut back to studio. The presenter looking at a monitor and then at a phone. Back to the film: a woman opens the door. She wears a dressing gown over lingerie. A shaky zoom in to reveal her clothing. Wide shot of the house with door shut. Jump cut to shot obviously taken from a window in the house. Shaky zoom in on window. We can see in the window...both the man and woman enter the bedroom. He goes out of shot, taking his coat off. Cut back to studio.
Presenter | He's being very brave here...
| Cut back to the film: even closer perhaps of window. A series of short jump cuts. She is undressing. She throws off her dressing gown. A jump and she's taking off her negligee. Underneath she wears black corsets. She produces a whip and seems to be beckoning to the man. Phone rings. Cut back to the studio. The presenter picks up the phone.
Presenter | Hello, sir, hello, yes. No sir, no, I'm sure you didn't. No, it's all right, sir, we don't morally censure, we just want the money....Yes, and here's the address to send it to:
Voice Over | (and CAPTION:) 'BLACKMAIL BEHIND THE HOT WATER PIPES THIRD WASHROOM ALONG VICTORIA STATION'
Presenter | Not at all, sir...thank you. (he puts the phone down)
| Cut to a hallway in which a middle-aged man in dinner dress is putting down the telephone rather furtively. He leaves the booth and goes through a door into a large room where a banquet is in progress. There are tables on three sides of a square and he joins the head table which faces as it were downstage. He sits beside other middle-aged and rather elderly men all of whom are the city of London ex-public school type. As he sits, the toastmaster standing behind speaks.
Man | Sorry chaps, it was my mother.
Toastmaster | Gentlemen, pray silence for the President of the Royal Society for Putting Things on Top of Other Things.
| There is much upperclass applause and banging on the table as Sir William rises to his feet.
Sir William | I thank you, gentlemen. The year has been a good one for the Society (hear, hear). This year our members have put more things on top of other things than ever before. But, I should warn you, this is no time for complacency. No, there are still many things, and I cannot emphasize this too strongly, not on top of other things. I myself, on my way here this evening, saw a thing that was not on top of another thing in any way. (shame!) Shame indeed but we must not allow ourselves to become too despondent. For, we must never forget that if there was not one thing that was not on top of another thing our society would be nothing more than a meaningless body of men that had gathered together for no good purpose. But we flourish. This year our Australasian members and the various organizations affiliated to our Australasian branches put no fewer than twenty-two things on top of other things. (applause) Well done all of you. But there is one cloud on the horizon. In this last year our Staffordshire branch has not succeeded in putting one thing on top of another (shame!). Therefore I call upon our Staffordshire delegate to explain this weird behaviour.
| As Sir William sits a meek man rises at one of the side tables.
Mr Cutler | Er, Cutler, Staffordshire. Um ... well, Mr Chairman, it's just that most of the members in Staffordshire feel... the whole thing's a bit silly.
| Cries of outrage. Chairman leaps to feet.
Sir William | Silly! SILLY!! (he pauses and thinks) Silly! I suppose it is, a bit. What have we been doing wasting our lives with all this nonsense? (hear, hear) Right, okay, meeting adjourned for ever.
| He gets right up and walks away from the table to approving noises and applause. He walks to a door at the side of the studio set and goes through it. Exterior shot: a door opens and Sir William appears out of it into the fresh air. He suddenly halts.
Sir William | Good Lord. I'm on film. How did that happen?
| He turns round and disappears into the building again. He reappears through door, crosses set and goes out through another door. He appears from the door into the fresh air and then stops.
Sir William | It's film again. What's going on?
| He turns and disappears through the door again. Cut to him inside the building. He crosses to a window and looks out, then turns and says...
Sir William | Gentlemen! I have bad news. This room is surrounded by film.
Members | What? What?
| Several members run to window and look out. Cut to film of them looking out of mindow. Cut to studio: the members run to a door and open it. Cut to film: of them appearing at the door hesitating and then closing door. Cut to studio: with increasing panic they run to the second door. Cut to film: they appear, hesitate, and go back inside. Cut to studio: they run to Sir William in the centre of the room.
A Member | We're trapped!
Sir William | Don't panic, we'll get out of this.
A Member | How?
Sir William | We'll tunnel our way out.
Barnes | Good thinking, sir. I'll get the horse.
Sir William | Okay Captain, you detail three men, start digging and load them up with cutlery, and then we'll have a rota, we'll have two hours digging, two hours vaulting and then two hours sleeping, okay?
| Barnes and others carry a vaulting horse into shot. The members start vaulting over it. Two Gestapo officers walk by.
Mr Cutler | All right, Medwin, let's see you get over that horse. Pick your feet up, Medwin. Come on, boy!
First German Officer (Ian Davidson) | Ze stupid English. Zey are prisoners and all they do is the sport.
Second German Officer | One thing worries me, Fritz.
First German Officer | Ja?
Second German Officer | Where's the traditional cheeky and lovable Cockney sergeant?
Sergeant | (donning tin helmet) Cheer up, Fritz, it may never happen (sing) Maybe it's because I'm a Londoner...
Second German Officer | Good. Everything seems to be in order.
| The Gestapo officers leave. Mr Cutler runs up to Sir William.
Mr Cutler | Colonel! I've just found another exit, sir.
Sir William | Okay, quickly, run this way.
Everyone | If we could run that way . .. (he stops them with a finger gesture) sorry.
| ANIMATION: A bleak landscape. A large foot with a Victorian lady on top of it comes hopping past. A door in a building opens and the society members (real people superimposed) run out, along the cartoon, and disappear, falling into nothingness. Cut to section of an oesophagus. The members (now animated cut-outs) fall down it into a stomach where they are joined by various large vegetables. Pull back to show that this is a cutaway view of an Edwardian gentleman. He belches.
Animation Voice | Oh, I'm terribly sorry, excuse me.
| He moves through a door marked 'gents'. We hear a lavatory flushing. Cut to café: linkman at table as before.
Linkman | Ah, hello. Well they certainly seem to be in a tight spot, and I spot... our next item - so let's get straight on with the fun and go over to the next item - or dish! Ha, ha!
| Cut to a simple set with two chairs in it. Close up of Mr Praline.
Praline | Hello. 'Ow are you? I'm fine. Welcome to a new half-hour chat show in which me, viz the man what's talking to you now, and Brooky - to wit my flat mate - and nothing else, I'd like to emphasize that - discuss current affairs issues of burning import.
| Pull back to show Brooky.
Brooky | Have you heard the one about the three nuns in the nudist colony?
Praline | Shut up. Tonight, the population explosion.
Brooky | Apparently there were these three nuns...
Praline | Shut up. Come the year 1991, given the present rate of increase in the world's population, the Chinese will be three deep. Another thing...
| Floor manager comes in.
Floor Manager | Sorry, loves, sorry, the show is too long this week and this scene's been cut.
Praline | Lord Hill's at the bottom of this.
Floor Manager | But if you can find a piano stool you can appear later on in the show on film.
Brooky | 'Ow much?
Floor Manager | Oh, about ten bob each?
Praline | I wouldn't wipe me nose on it.
Brooky | 'Ave you 'eard the one about these three nuns...
Praline | Shh. I can hear something. 'Ang about, we may still get in this show as a link.
| Praline kneels and puts his ear to the floor. In the bottom section of the shot we see beneath the floor an animation of the unfortunate members of the Society for Putting Things on Top of Other Things being flushed along a pipe.
Brooky | That's clever. How do they do that?
Praline | Colour separation, you cotton head.
| ANIMATION: various adventures of the Society members. Cut back to linkman. There is a loud argument going on in the café behind him.
Linkman | Well, they seem to be in another tight spot...(to the argument) Could you...could you, could you keep it down a little, please. Thank you so much. Could you keep it down please...Thank you. (to camera) Well and now we move on to our, to our main course. Prawn salad...Prawn salad?
| Oak-panelled door with notice on it saying 'Prawn Salad Ltd'. The butler pushes it open and shows man into living room. The room is fairly large, containing at one end opposite the door a big window, making the room look quite high up - although it should be stately rather than modern. In the middle of the room's back wall there is a large ornate mirror, over a mantelpiece filled with objects. To the right of this wall there is a large bookshelf filled with books, and in front of it there is a drinks trolley.
Butler | Well, if you'll just wait in here, sir, I'm sure Mr Thompson won't keep you waiting long.
Man | Fine. Thanks very much.
| He picks up a magazine. The mirror behind him without warning falls off the wall and smashes to the ground. The butler returns, and looks at the man enquiringly.
Man | The mirror fell off the wall.
Butler | Sir?
Man | The mirror fell off... off the wall... it fell.
Butler | (disbelieving but polite) I see. You'd better wait here. I'll get a cloth.
| The butler just closes the door behind him and the bookcase detaches itself from the wall and comes sweeping down, bringing with it the drinks trolley. The butler opens the door.
Man | Ah, it ... it came off the wall.
Butler | Yes, sir?
Man | It just came right off the wall.
Butler | Really, sir.
Man | Yes, I ... I didn't touch it.
Butler | (politely ironic) Of course not. It just fell off the wall.
Man | Yes. It just fell off the wall.
Butler | Don't move. I'll get help.
| He goes.
Man | Yes - er, fell off the wall.
| A maid enters.
Maid | Oh my God, what a mess. 'Ere, did you do this?
Man | No, no. I didn't do all this. It... it did it all.
Maid | Oh? Well... 'ere, hold this. I'll get started.
| She hands him a dagger.
Man | Oh, it's jolly nice. What is it?
Maid | It's a Brazilian dagger. Ooops.
| She trips, falls lethally on to the dagger he is holding. She collapses at his feet. There is blood on the dagger and his hand. He is looking down at her, when he becomes aware of a man in a green baize apron at the door, who is looking at him in horror.
Man | Er, she just fell on ... on to the dagger.
Green | (soothingly) Yes, of course she did, sir.
Man | Yes, just gave me the dagger and tripped, and went, 'Oops'.
| Green starts backing round the room away from him, but humouring him.
Green | Yes sir, I understand.
Man | I mean, I didn't er...
Green | Oh no, no, of course not, sir, I understand.
Man | I mean she ... she just, er...
Green | Fell?
Man | Fell.
Green | (backs off too far and falls backwards through the window) Arrghh!
Man | (to window) I'm terribly sorry.
| A policeman and the butler appear at the door.
Butler | That's him.
Policeman | Right, sir.
Man | Hello, officer. There seems to have been an accident. Well, several accidents actually.
Policeman | That's right, sir. Would you come this way, please. (goes towards him) Ahh! (clutches chest) It's me ... me heart, sir. (collapses)
Butler | You swine. I'll get you for that.
| He is about to move forward when a large portion of the ceiling collapses on him. He goes down, too.
Man | Er, I won't wait. I'll phone.
| He moves off through door. Large crashing sounds. He comes downstairs into a stretch of hall leading to an outside door. As he comes suits of armour collapse, bookcase glass smashes, a grandfather clock tips over and smashes, pictures fall off walls. All this quite quickly in sequence as he passes in horror. He gets to the main door. We see his relief. He closes the main door behind him, slamming it: it's a country-house-type entrance. Cut to stock film of country house being blown up. Cut back to man looking in horror, with dust and rubble swirling around. He is holding the remains of the door.
Man | Sorry.
| Pull wide. He is in a patch of rubble. The Society for Putting Things on Top of Other Things members walk by in their evening dress.
Members | I think we're really out this time. Yes. Jolly good. Now where's the school hall. I think it's over there. Come on. Sorry. Jolly good.
| They go past the bishop in the field.
Bishop | (singing) Oh, Mr Belpit. Your legs are so swollen.
Sir William | Excuse me, is that the school hall?
Bishop | Um, I'm sorry, I don't know. I'm not in this one - I'm in next week's, I think.
Sir William | Oh, come on.
Bishop | Oh, Mr Belpit!...
| They come to a school hall. A sign says 'Seven Brides for Seven Brothers, presented by the staff and pupils of the Dibley School for Boys'.
Sir William | Oh, here we are. (they go in)
| Cut to linkman in cafeteria.
Linkman | Ah well, they seem to have linked that themselves, so there's no need for me to interrupt at all. So, ah, back to the school hall.
| A school hall with a stage. Mr Praline and Brooky enter. Praline sits at piano and plays something very badly; Brooky turns the pages for him. Music ends. Unseen schoolmaster announcer:
Schoolmaster | 'Seven Brides for Seven Brothers'. (slight applause)
| The curtain pans. Enter headmaster in mortar board and gown.
Headmaster | 'Tis time the seven Smith brothers had brides. Fetch me Smith Major.
| Enter Smith Major in short pants.
First Smith | Sir.
Headmaster | 'Tis time you and your six brothers were married.
First Smith | Thank you, Headmaster.
Headmaster | Fetch me your six brothers, that the seven brothers may be together.
| Smith Major rings handbell. Three boys enter and stand next to him.
Boys | Behold, the seven brothers.
Headmaster | Right, I'll see Watson, Wilkins, and Spratt in my study afterwards.
First Smith | (has to be prompted, then declaims badly) But where shall we find seven brides for seven brothers?
Second Smith | The Sabine School for Girls.
Third Smith | Yes, and it's the Annual Dance.
Headmaster | Fetch hither the seven brides for seven brothers.
| Enter two schoolgirls.
Two Girls | Behold the seven brides.
Headmaster | Fetch hither the padre that the seven brides may marry the seven brothers. (nothing happens) Fetch hither the master on duty that the seven brides may marry the seven brothers.
Padre | (entering) Sorry, I'm late, Headmaster - I've been wrestling with Plato.
Headmaster | What you do in your own time, Padre, is written on the wall in the vestry.
Padre | Right, do you four boys take these two girls to be your seven brides?
Boys | Yes, sir.
Padre | Right, go and do your prep.
| The curtain comes across quickly. Animation sketch links us to a butcher's shop. Harmless looking city gent enters.
Gent | Good morning, I'd care to purchase a chicken, please.
Butcher | Don't come here with that posh talk you nasty, stuck-up twit.
Gent | I beg your pardon?
Butcher | A chicken, sir. Certainly.
Gent | Thank you. And how much does that work out to per pound, my good fellow?
Butcher | Per pound, you slimy trollop, what kind of a ponce are you?
Gent | I'm sorry?
Butcher | 4/6 a pound, sir, nice and ready for roasting.
Gent | I see, and I'd care to purchase some stuffing in addition, please.
Butcher | Use your own, you great poofy poonagger!
Gent | What?
Butcher | Ah, certainly sir, some stuffing.
Gent | Oh, thank you.
Butcher | 'Oh, thank you' says the great queen like a la-di-dah poofta.
Gent | I beg your pardon?
Butcher | That's all right, sir, call again.
Gent | Excuse me.
Butcher | What is it now, you great pillock?
Gent | Well, I can't help noticing that you insult me and then you're polite to me alternately.
Butcher | I'm terribly sorry to hear that, sir.
Gent | That's all right. It doesn't really matter.
Butcher | Tough titty if it did, you nasty spotted prancer.
| Cut to the Grillomat in Paignton. The announcer is just handing back a cup and saucer to a waitress.
Linkman | Sorry, I asked for tea. (she takes it grudgingly) Thank you very much. (to camera) Well we've had the dessert and then, and so the first item, the last item on our menu of fun is the coffee. (waitress hands him back his cup) Now I did ask for tea.
Waitress | But you just said coffee.
Linkman | No, no, that was just my announcement, just a metaphor.
| She shrugs and begins to move off. At the table just behind him we hear her complaining noisily in the background.
Linkman | We come...look would you mind keeping it down, please...we come as - as I said just now, to the coffee.
Waitress | Here, he said it again!
Linkman | Shut up!
| Film of a boxer (John) in training, running along a country road. All this is shot in 'Man Alive' style: plenty of hand-held documentary work. Sound of boxer's feet on the leaves and heavy breathing.
Voice Over | This is Ken Clean-Air Systems, the great white hope of the British boxing world. After three fights - and only two convictions - his manager believes that Ken is now ready to face the giant American, Satellite Five.
| Cut to manager being driven in Rolls. SUPERIMPOSED CAPTION: 'MR ENGLEBERT HUMPERDINCK - MANAGER'
Manager | The great thing about Ken is that he's almost totally stupid.
| Cut back to Ken jogging, the early morning sun filtering through the trees.
Voice Over | Every morning, he jogs the forty-seven miles from his two-bedroomed, eight-bathroom, six-up-two-down, three-to-go-house in Reigate, to the Government's Pesticide Research Centre at Shoreham. Nobody knows why.
| Cut to Ken's wife (a young married with her head in a scarf and curlers), hanging out the washing in a council estate. CAPTION: 'MRS CLEAN-AIR SYSTEMS'
Mrs CAS | Basically Ken is a very gentle, home-loving person. I remember when one of his stick insects had a knee infection. He stayed up all night rubbing it with germoline and banging its head on the table.
| Cut to Ken's mother - an old lady in a wheelchair. Hand-held big close-up against the sky. CAPTION: 'MRS NELLIE AIR-VENT, MOTHER'
Mother | Oh he was such a pretty baby, always so kind and gentle. He was really considerate to his mother, and not at all the kind of person you'd expect to pulverize their opponent into a bloody mass of flesh and raw bone, spitting teeth and fragments of gum into a ring which had become one man's hell and Ken's glory.
| The wheelchair moves away and we see that it is on top of a car. Cut to exterior of a semi-detached house. Night.
Voice Over | Every morning at his little three-room semi near Reading, Ken gets up at three o'dock (light goes on) and goes back to bed again because it's far too early.
| Light goes out. Close-up alarm clock at 7.05. General shot of room, Ken coming out of bathroom pulling his track-suit on.
Voice Over | At seven o'clock Ken gets up, he has a quick shower, a rub-down, gets into his track-suit, and goes back to bed again. (shot of trainer running) At 7.50 every morning Ken's trainer runs the 13,000 miles from his two-room lean-to in Bangkok and gets him up.
| General shot of room to show his trainer standing over the sleeping Ken. He holds a large mallet and a steel peg.
Trainer | I used to wake Ken up with a crowbar on the back of the head. But I recently found that this was too far from his brain and I wasn't getting through to him anymore. So I now wake him up with a steel peg driven into his skull with a mallet.
| Cut to the empty kitchen, shot from ground level. The camera pans across to show plate of food under an upright chair, and then pans across the room to the kitchen cupboard; Mrs Clean-Air Systems at the sink.
Voice Over | For breakfast every day, Ken places a plate of liver and bacon under his chair, and locks himself in the cupboard.
| Cut to gym. Manager standing beside ropes of the ring. Again a hand-held 'Man Alive' type interview, with camera noise and all.
Manager | Well, he's having a lot of mental difficulties with his breakfasts, but this is temperament, caused by a small particle of brain in his skull, and once we've removed that he'll be perfectly all right.
| Close-up alarm clock. Hands at 8.30.
Voice Over | At 8.30 the real training begins. (General shot of room. Ken asleep in bed) Ken goes back to bed and his trainer gets him up. (The door bursts open but we don't stay to see what happens. We cut immediately to outside of the house. His trainer pushes Ken out. Trainer goes back into the house (obviously to Ken's wife). Cut to Ken jogging through town. Hand held. Ken finds his way blocked by a parked car. He stops and looks very puzzled, then instead of going round it turns and runs back the way he has come.) At 10.30 every morning Ken arrives at what he thinks is the gym. Sometimes it's a sweetshop, sometimes it's a private house. Today its a hospital.
| Ken turns into the gates of a hospital. There is a slight pause, and a white-coated doctor arrives at the door and points right up the street.
Doctor | Urn, straight down there. Straight down there.
| Ken follows his finger and looks very hard in that direction. When he is satisfied that Ken has understood where he is pointing, the doctor retires back inside. Ken turns and watches him as he does this, then turns and sets off in the opposite direction. Cut to a shot of a roadside diner.
Voice Over | For lunch Ken crouches down in the road and rubs gravel into his hair. (Pan down to roadside to reveal Ken just finishing rubbing gravel into his hair; he stands up and hops over a railing to a riverside where a bed stands) But lunch doesn't take long. Ken's soon up on his feet and back to bed. (Ken hops into the bed) And his trainer has to run the 49,000 miles from his two-bedroom, six-living-room tree-house in Kyoto to wake him up. (Trainer runs into shot, pauses by bedside and turns to camera. He has large plumber's bag.)
Trainer | Hello. When Ken is in a really deep sleep like this one, the only way to wake him up is to saw his head off.
| Cut to stock close-up of punchbag and glove smashing into it. Continual hitting and impact-bang-bang-bang-bang throughout.
Voice Over | What is he like in the ring, this human dynamo, this eighteen-stone bantam weight battering-ram? We asked his sparring partner and one-time childhood sweetheart, Maureen Spencer.
| Cut to medium close-up of Maureen, very busty in boxing gear and sparring helmet.
Maureen | Well, I think that if Ken keeps his right up, gets in with the left jab and takes the fight to his man - well, he should go for a cut eye in the third and put Wilcox on the canvas by six.
| She goes back to sparring and we see it is she who is hitting the punchbag. Remaining on her we hear the voice over.
Voice Over | Ken's opponent in Tuesday's fight is Petula Wilcox, the Birmingham girl who was a shorthand typist before turning pro in 1968. (Cut to typical teenage girl's bedside. Pin-ups of popstars on the walls. Teddy bears on the bed and gonks. Petula Wilcox is sitting up on the bed knitting.) She's keen on knitting and likes Cliff Richard records. How does she rate her chances against Ken?
Petula (Connie Booth) | Well, I'm a southpaw and I think this will confuse him, particularly with his brain problem.
| Cut to the ring. Floodlight. The night of the big fight. Murmur of a huge crowd. Excitement, cigar smoke rising in front of the camera. Bustle of activity all around. In medium close-up the master of ceremonies walks out into the middle of the ring, and takes the microphone.
Master of Ceremonies | My lords, ladies and gedderbong... On my right, from the town of Reigate in the county of Kent, the heavyweight... (unintelligible) Mr Ken Clean-Air Systems!... (applause, cut to Ken's corner; Ken raises his arms above his head) and on my left! Miss Petula Wilcox.
| SUPERIMPOSED CAPTION: ROUND 1 For the first time we see Petula dance out into the middle of the ring, frail and lovely in a white muslin dress, with a bow in her hair and boxing gloves. The referee bring them together, cautions them and then they separate. The bell goes. As speeded-up as we can manage and with the same stupendous sound effects as for all-in cricket, Ken belts the hell out of Petula. While this goes on, we hear a few voice overs.
Colonel Type | I think boxing's a splendid sport - teaches you self-defense.
Critic | Obviously boxing must have its limits, but providing they're both perfectly fit I can see nothing wrong with one healthy man beating the living daylights out of a little schoolgirl.
Voice | It's quick and it's fun.
| Boxing match is still in full swing as we cut away to the Grillomat snack bar. A dim light; the announcer has gone. There is only the waitress setting chairs on the tables, and cleaning. She looks up as the camera comes on her.
Waitress | Oh, no, he's gone. But he left a message. Jack! Where's that note that fellow left?
Jack | Oh, here you are.
Waitress | It says sorry, had to catch the last bus. Am on the 49b to Babbacombe.
| Cut to the top of an open-top bus driving along.
Linkman | Oh, er, there you are. Hello. You got the note, jolly good. Well, um, that's all the items that we have for you this week and er, what a jolly nice lot of items too, eh? Um...well, the same team will be back with you again next week with another menu full of items. Um...I don't know if I shall be introducing the show next week as I understand my bits in this show have not been recieved quite as well as they might (start to roll credits over this) but er, never mind, the damage is done - no use in crying over spilt milk. (miserably) I've had my chance and I've muffed it. Anyway, there we are. I'm not really awfully good with words. You see, I'm more of a visual performer. I have a very funny - though I say so myself - very funny funny walk. I wish I'd been in that show. I'd have done rather well. But anyway, there we are - the show's over. And...we'll all be - they'll all be back with you again next week... (starting to cry) Sorry. I do beg your pardon. I don't like these...displays of emotion...I wish it would say the end.
| It says 'The End'.